Integrating with Django Reversion — Django Stories v0.2 documentation

Django Stories v0.2 documentation

# Integrating with Django Reversion

- Table of Contents
- index
  next
  previous

# Integrating with Django Reversion

1. Install django-reversion

       pip install django-reversion

2. Add `reversion` to your `INSTALLED_APPS` setting.

3. `./manage.py syncdb`

All the hooks are there to notice when reversion is installed. Versions are tracked from when reversion is first installed.